import { type InternalOptions } from '../types/options.js';
export type DelayOptions = {
    signal?: InternalOptions['signal'];
};
export default function delay(ms: number, { signal }: DelayOptions): Promise<void>;
