"use strict";

var value                   = require("./valid-value")
  , objPropertyIsEnumerable = Object.prototype.propertyIsEnumerable;

module.exports = function (obj) {
	var i;
	value(obj);
	for (i in obj) {
		// Jslint: ignore
		if (objPropertyIsEnumerable.call(obj, i)) return false;
	}
	return true;
};
