// Export all modules.

"use strict";

module.exports = {
	"#": require("./#"),
	"constant": require("./constant"),
	"identity": require("./identity"),
	"invoke": require("./invoke"),
	"isArguments": require("./is-arguments"),
	"isFunction": require("./is-function"),
	"noop": require("./noop"),
	"pluck": require("./pluck"),
	"validFunction": require("./valid-function")
};
