import type { SearchParamsOption } from '../types/options.js';
export declare const findUnknownOptions: (options: Record<string, unknown>) => Record<string, unknown>;
export declare const hasSearchParameters: (search: SearchParamsOption) => boolean;
