"use strict";

module.exports = {
	isSticky: require("./is-sticky"),
	isUnicode: require("./is-unicode"),
	match: require("./match"),
	replace: require("./replace"),
	search: require("./search"),
	split: require("./split")
};
