import { EnsureBaseOptions, EnsureIsOptional, EnsureDefault } from '../ensure';

declare function ensureTimeValue(value: any, options?: EnsureBaseOptions & EnsureIsOptional): number | null;
declare function ensureTimeValue(value: any, options?: EnsureBaseOptions & EnsureIsOptional & EnsureDefault<number>): number;
export default ensureTimeValue;
