/**
 * Run a command (as a promise).
 * @param command command to run
 * @param args args to pass
 * @returns promise that yields true if success
 */
export declare function runCommand(command: string, args?: string[], stdOutToLogs?: boolean): Promise<boolean>;
/**
 * Check if password input is necessary for signing
 * @returns promise that yieds true if password is required
 */
export declare function isPasswordRequired(): Promise<boolean>;
export default runCommand;
