"use strict";

module.exports = {
	compose: require("./compose"),
	copy: require("./copy"),
	curry: require("./curry"),
	lock: require("./lock"),
	microtaskDelay: require("./microtask-delay"),
	not: require("./not"),
	partial: require("./partial"),
	spread: require("./spread"),
	toStringTokens: require("./to-string-tokens")
};
