export type ArtixRepo = 'system' | 'system-gremlins' | 'system-goblins' | 'world' | 'world-gremlins' | 'world-goblins' | 'galaxy' | 'galaxy-gremlins' | 'galaxy-goblins' | 'lib32' | 'lib32-gremlins' | 'lib32-goblins';
export type ArchRepo = 'core' | 'core-testing' | 'core-staging' | 'extra' | 'extra-testing' | 'extra-staging' | 'multilib' | 'multilib-testing' | 'multilib-staging';
export type ValidFlag = '-u' | '-m' | '-ml';
export interface CheckupdatesOptions {
    timeout?: number;
}
export interface CheckupdatesResult {
    basename: string;
    artixRepo: ArtixRepo;
    artixVersion: string;
    archRepo: ArchRepo;
    archVersion: string;
    packager: string;
}
export declare class Checkupdates {
    private _timeout;
    constructor(options?: CheckupdatesOptions);
    cleanUpLockfiles(): Promise<void>;
    applyCompliance(str: string): string;
    parseCheckUpdatesOutput(output: string, applyCompliance?: boolean): CheckupdatesResult[];
    checkupdates(flag: ValidFlag, applyCompliance?: boolean): Promise<CheckupdatesResult[]>;
    retryCheckupdates(flag: ValidFlag, applyCompliance?: boolean, retries?: number, pause?: number): Promise<CheckupdatesResult[]>;
    fetchUpgradable(applyCompliance?: boolean, retries?: number): Promise<CheckupdatesResult[]>;
    fetchMovable(applyCompliance?: boolean, retries?: number): Promise<CheckupdatesResult[]>;
    fetchLooseMovable(applyCompliance?: boolean, retries?: number): Promise<CheckupdatesResult[]>;
}
export default Checkupdates;
