import type { PathLike } from 'node:fs';
export interface ArtoolsConf {
    workspace: string;
    giteaToken: string | null;
}
export declare const DefaultConf: ArtoolsConf;
export declare class ArtoolsConfReader {
    readConf(silent?: boolean): Promise<ArtoolsConf>;
    readConfFile(file: PathLike): Promise<ArtoolsConf>;
}
export default ArtoolsConfReader;
