export type { ArtoolsConf } from './artoolsconf.js';
export type { GiteaConfig } from './gitea.js';
export type { GitlabConfig } from './gitlab.js';
export type { Job, PusherConfig } from './pusher.js';
export declare function artixMetro(): Promise<void>;
export default artixMetro;
