"use strict";

module.exports = {
	global: require("./global"),
	optionalChaining: require("./optional-chaining"),
	safeToString: require("./safe-to-string"),
	toShortStringRepresentation: require("./to-short-string-representation"),

	array: require("./array"),
	boolean: require("./boolean"),
	date: require("./date"),
	error: require("./error"),
	function: require("./function"),
	iterable: require("./iterable"),
	json: require("./json"),
	math: require("./math"),
	number: require("./number"),
	object: require("./object"),
	promise: require("./promise"),
	regExp: require("./reg-exp"),
	string: require("./string")
};
