import type { TracingChannel, Channel } from 'node:diagnostics_channel';
export type { TracingChannel, Channel };
export declare const metrics: Channel<unknown>;
export declare const tracing: TracingChannel<unknown>;
//# sourceMappingURL=diagnostics-channel.d.ts.map